@@ -510,6 +510,28 @@ class SQLEnumerable:
 
         return self
 
+    def simple_insert(self, **kwargs: dict[str, Any]) -> SQLEnumerable:
+        """
+        Add an Insert command to the command list. Only for relationnal table.
+
+        You give all column name with the name of kwargs and value in args.
+
+        Args:
+            **kwargs: All data and name of the column is the key in kwargs.
+
+        Returns:
+            Self.
+
+        Raises:
+            ReadOnlyPermissionDeniedError: Indirect raise by `self.insert`.
+            AlterError: Indirect raise by `self.insert`.
+            AlreadyExecutedError: Indirect raise by `self.insert`.
+            MoreThanZeroError: Indirect raise by `self.insert`.
+            OneError: Indirect raise by `self.insert`.
+            TerminalError: Indirect raise by `self.insert`.
+        """
+        return self.insert(column=list(kwargs.keys()), data=tuple(kwargs.values()))
+
     def update(self, fquery: Callable[[MagicDotPath], MagicDotPath]) -> SQLEnumerable:
         """
         Add an UPDATE command to the command list.
