@@ -48,7 +48,7 @@ else:
     from strenum import LowercaseStrEnum as StrEnum  # pragma: no cover
 
 
-_OTHER_TYPE = float | int | str | list | dict | Decimal
+_VALID_OPERAND_TYPE = float | int | str | list | dict | Decimal
 _OPERATORTYPE = (
     HyperBFuncType | MathFunctType | OperatorType | TrigoFunctType | StrFunctType
 )
@@ -131,9 +131,25 @@ class BaseMagicDotPath:
         # No cover because is just a wrapper for subclasses.
         raise NotImplementedError  # pragma: no cover
 
+    def __getitem__(self, attribute_name: str) -> BaseMagicDotPath:
+        """
+        Get items in a list for a MagicDotPath objects.
+
+        Args:
+            attribute_name: Names of all attributes.
+
+        Returns:
+            A MagicDotPath objects with attributes names in attributes list.
+
+        Raises:
+            NotImplementedError: This function is just a wrapper for the subclasses.
+        """
+        # No cover because is just a wrapper for subclasses.
+        raise NotImplementedError  # pragma: no cover
+
     def _get_number_operator(
         self,
-        other: _OTHER_TYPE | BaseMagicDotPath,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
         operator: _OPERATORTYPE,
     ) -> MagicDotPathWithOp:
         """
@@ -175,7 +191,7 @@ class BaseMagicDotPath:
 
     def _get_generic_operator(
         self,
-        other: _OTHER_TYPE,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
         operator: _OPERATORTYPE,
     ) -> MagicDotPathWithOp:
         """
@@ -204,7 +220,10 @@ class BaseMagicDotPath:
             case str():
                 other_type = str
             case list():
-                other_type = list
+                if operator == OperatorType.IN:
+                    other_type = str
+                else:
+                    other_type = list
             case dict():
                 other_type = dict
             case BaseMagicDotPath():
@@ -240,7 +259,10 @@ class BaseMagicDotPath:
             my_type=NoneType,
         )
 
-    def __gt__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __gt__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `>` operator and the correct types.
 
@@ -257,7 +279,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.GT)
 
-    def __lt__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __lt__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `<` operator and the correct types.
 
@@ -274,7 +299,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.LT)
 
-    def __ge__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __ge__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `>=` operator and the correct types.
 
@@ -291,7 +319,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.GE)
 
-    def __le__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __le__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `<=` operator and the correct types.
 
@@ -310,7 +341,7 @@ class BaseMagicDotPath:
 
     def __eq__(  # type: ignore[override]
         self,
-        other: _OTHER_TYPE,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
     ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `=` operator and the correct types.
@@ -330,7 +361,7 @@ class BaseMagicDotPath:
 
     def __ne__(  # type: ignore[override]
         self,
-        other: _OTHER_TYPE,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
     ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `<>` operator and the correct types.
@@ -348,7 +379,10 @@ class BaseMagicDotPath:
         """
         return self._get_generic_operator(other, OperatorType.NE)
 
-    def __add__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __add__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `+` operator and the correct types.
 
@@ -365,7 +399,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.ADD)
 
-    def __radd__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __radd__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `+` operator and the correct types.
 
@@ -385,7 +422,10 @@ class BaseMagicDotPath:
         """
         return self.__add__(other)
 
-    def __sub__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __sub__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `-` operator and the correct types.
 
@@ -402,7 +442,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.SUB)
 
-    def __rsub__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __rsub__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `-` operator and the correct types.
 
@@ -424,7 +467,10 @@ class BaseMagicDotPath:
         mdp_with_op.operand_1 = other
         return mdp_with_op
 
-    def __mul__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __mul__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `*` operator and the correct types.
 
@@ -441,7 +487,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.MUL)
 
-    def __rmul__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __rmul__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `*` operator and the correct types.
 
@@ -461,7 +510,10 @@ class BaseMagicDotPath:
         """
         return self.__mul__(other)
 
-    def __truediv__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __truediv__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `/` operator and the correct types.
 
@@ -478,7 +530,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.TRUEDIV)
 
-    def __rtruediv__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __rtruediv__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `/` operator and the correct types.
 
@@ -500,7 +555,10 @@ class BaseMagicDotPath:
         mdp_with_op.operand_1 = other
         return mdp_with_op
 
-    def __mod__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __mod__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `%` operator and the correct types.
 
@@ -517,7 +575,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.MOD)
 
-    def __rmod__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __rmod__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `%` operator and the correct types.
 
@@ -539,7 +600,10 @@ class BaseMagicDotPath:
         mdp_with_op.operand_1 = other
         return mdp_with_op
 
-    def __and__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __and__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `AND` operator and the correct types.
 
@@ -556,7 +620,10 @@ class BaseMagicDotPath:
         """
         return self._get_generic_operator(other, OperatorType.AND)
 
-    def __rand__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __rand__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `AND` operator and the correct types.
 
@@ -576,7 +643,10 @@ class BaseMagicDotPath:
         """
         return self.__and__(other)
 
-    def __or__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __or__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `OR` operator and the correct types.
 
@@ -593,7 +663,10 @@ class BaseMagicDotPath:
         """
         return self._get_generic_operator(other, OperatorType.OR)
 
-    def __ror__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __ror__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `OR` operator and the correct types.
 
@@ -622,7 +695,10 @@ class BaseMagicDotPath:
         """
         return self._get_one_operand_operator(OperatorType.INVERT)
 
-    def __pow__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __pow__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `^` operator.
 
@@ -637,7 +713,10 @@ class BaseMagicDotPath:
         """
         return self._get_number_operator(other, OperatorType.POW)
 
-    def __rpow__(self, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+    def __rpow__(
+        self,
+        other: _VALID_OPERAND_TYPE | BaseMagicDotPath,
+    ) -> MagicDotPathWithOp:
         """
         Get a MagicDotPathWithOp objects with a `^` operator and the correct types.
 
@@ -761,6 +840,18 @@ class MagicDotPath(BaseMagicDotPath):
             with_table=self.with_table,
         )
 
+    def __getitem__(self, attribute_name: str) -> MagicDotPath:
+        """
+        Get attr from the dict syntax.
+
+        Args:
+            attribute_name: Names of all attributes.
+
+        Returns:
+            A MagicDotPath objects with attributes names in attributes list.
+        """
+        return self.__getattr__(attribute_name)
+
     def safe(self, name: str) -> str:
         """
         Secure a column or a table for a request.
@@ -847,9 +938,9 @@ class MagicDotPathWithOp(BaseMagicDotPath):
 
     """
 
-    operand_1: BaseMagicDotPath | _OTHER_TYPE
+    operand_1: BaseMagicDotPath | _VALID_OPERAND_TYPE
     operator: _OPERATORTYPE
-    operand_2: BaseMagicDotPath | _OTHER_TYPE | None
+    operand_2: BaseMagicDotPath | _VALID_OPERAND_TYPE | None
     my_type: Type[Any]
 
     def jsonb_path(self, as_str: bool) -> str:
@@ -884,7 +975,12 @@ class MagicDotPathWithOp(BaseMagicDotPath):
                 operand_2_in_good_format = json.dumps(self.operand_2)
                 path_op.op2 = f"'{operand_2_in_good_format}'::jsonb"
             case list():
-                path_op.op2 = f"'{self.operand_2}'::jsonb"
+                if self.operator in [OperatorType.IN]:
+                    path_op.op2 = (
+                        f"""({", ".join([f"'{val}'" for val in self.operand_2])})"""
+                    )
+                else:
+                    path_op.op2 = f"'{self.operand_2}'::jsonb"
             case _:
                 path_op.op2 = str(self.operand_2)
 
@@ -896,6 +992,7 @@ class MagicDotPathWithOp(BaseMagicDotPath):
                 OperatorType.ABS,
                 OperatorType.POS,
                 OperatorType.NEG,
+                OperatorType.IN,
             ]:
                 result = json_path_ope(path_op, self.operator)
             case type() if isinstance(self.operator, HyperBFuncType):
@@ -949,6 +1046,8 @@ class MagicDotPathWithOp(BaseMagicDotPath):
                 name_op.op2 = self.operand_2.col_name()
             case float() | int() | Decimal():
                 name_op.op2 = _clean_number_str(str(self.operand_2))
+            case list():
+                name_op.op2 = f"""({','.join([str(val) for val in self.operand_2])})"""
 
         operator = self.operator
         match operator:
