@@ -91,6 +91,7 @@ class OperatorType(_Operator, Enum):
     POW = _Operator(python="**", psql="^", name="pow")
     SUB = _Operator(python="-", psql="-", name="sub")
     TRUEDIV = _Operator(python="/", psql="/", name="div")
+    IN = _Operator(python="in", psql="IN", name="in")
 
 
 class TrigoFunctType(_TrigoFunction, Enum):
@@ -340,7 +341,7 @@ def json_path_ope(path_op: DotMap, operator: _OPERATORTYPE) -> str:
     if not isinstance(operator, OperatorType):
         raise TypeOperatorError([OperatorType], type(operator))
 
-    if operator in [OperatorType.AND, OperatorType.OR]:
+    if operator in [OperatorType.AND, OperatorType.OR, OperatorType.IN]:
         return f"{path_op.op1} {operator.psql} {path_op.op2}"
 
     if operator in [OperatorType.INVERT]:
