@@ -7,7 +7,7 @@ from decimal import Decimal
 from ..classes.magicdotpath import BaseMagicDotPath, MagicDotPathWithOp
 from ..classes.op_and_func_of_mdp import MathFunctType
 
-_OTHER_TYPE = float | int | Decimal
+_NUMBER_TYPE = float | int | Decimal
 
 
 def cbrt(mdp: BaseMagicDotPath) -> MagicDotPathWithOp:
@@ -124,7 +124,7 @@ def floor(mdp: BaseMagicDotPath) -> MagicDotPathWithOp:
     )
 
 
-def gcd(mdp: BaseMagicDotPath, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+def gcd(mdp: BaseMagicDotPath, other: _NUMBER_TYPE) -> MagicDotPathWithOp:
     """
     Gcd function for a MagicDotPath.
 
@@ -150,7 +150,7 @@ def gcd(mdp: BaseMagicDotPath, other: _OTHER_TYPE) -> MagicDotPathWithOp:
     )
 
 
-def lcm(mdp: BaseMagicDotPath, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+def lcm(mdp: BaseMagicDotPath, other: _NUMBER_TYPE) -> MagicDotPathWithOp:
     """
     Lcm function for a MagicDotPath.
 
@@ -235,7 +235,7 @@ def log10(mdp: BaseMagicDotPath) -> MagicDotPathWithOp:
     )
 
 
-def log(mdp: BaseMagicDotPath, other: _OTHER_TYPE) -> MagicDotPathWithOp:
+def log(mdp: BaseMagicDotPath, other: _NUMBER_TYPE) -> MagicDotPathWithOp:
     """
     Log function for a MagicDotPath.
 
@@ -300,7 +300,7 @@ def radians(mdp: BaseMagicDotPath) -> MagicDotPathWithOp:
 
 def round(  # noqa: A001
     mdp: BaseMagicDotPath,
-    other: _OTHER_TYPE | None = None,
+    other: _NUMBER_TYPE | None = None,
 ) -> MagicDotPathWithOp:
     """
     Round function for a MagicDotPath.
@@ -397,7 +397,7 @@ def trim_scale(mdp: BaseMagicDotPath) -> MagicDotPathWithOp:
 
 def trunc(
     mdp: BaseMagicDotPath,
-    other: _OTHER_TYPE | None = None,
+    other: _NUMBER_TYPE | None = None,
 ) -> MagicDotPathWithOp:
     """
     Trunc function for a MagicDotPath.
